@@ -11,6 +11,7 @@ from tryton.gui.window import Window
 from tryton.gui.window.win_export import WinExport
 from tryton.gui.window.win_import import WinImport
 from tryton.gui.window.attachment import Attachment
+from tryton.gui.window.note import Note
 from tryton.gui.window.revision import Revision
 from tryton.signal_event import SignalEvent
 from tryton.common import message, sur, sur_3b, timezoned_date
@@ -44,6 +45,8 @@ class Form(SignalEvent, TabContent):
         (None,) * 5,
         ('attach', 'tryton-attachment', _('Attachment(0)'),
             _('Add an attachment to the record'), 'sig_attach'),
+        ('note', 'tryton-note', _('Note(0)'),
+            _('Add a note to the record'), 'sig_note'),
     ]
     menu_def = [
         (_('_New'), 'tryton-new', 'sig_new', '<tryton>/Form/New'),
@@ -69,6 +72,7 @@ class Form(SignalEvent, TabContent):
         (None,) * 4,
         (_('A_ttachments...'), 'tryton-attachment', 'sig_attach',
             '<tryton>/Form/Attachments'),
+        (_('_Notes...'), 'tryton-note', 'sig_note', '<tryton>/Form/Notes'),
         (_('_Actions...'), 'tryton-executable', 'sig_action',
             '<tryton>/Form/Actions'),
         (_('_Relate...'), 'tryton-go-jump', 'sig_relate',
@@ -89,7 +93,7 @@ class Form(SignalEvent, TabContent):
 
     def __init__(self, model, res_id=False, domain=None, order=None, mode=None,
             view_ids=None, context=None, name=False, limit=None,
-            search_value=None, tab_domain=None):
+            search_value=None, tab_domain=None, context_model=None):
         super(Form, self).__init__()
 
         if not mode:
@@ -109,7 +113,8 @@ class Form(SignalEvent, TabContent):
 
         self.screen = Screen(self.model, mode=mode, context=context,
             view_ids=view_ids, domain=domain, limit=limit, order=order,
-            search_value=search_value, tab_domain=tab_domain)
+            search_value=search_value, tab_domain=tab_domain,
+            context_model=context_model)
         self.screen.widget.show()
 
         if not name:
@@ -133,12 +138,7 @@ class Form(SignalEvent, TabContent):
             style.bg[gtk.STATE_INSENSITIVE])
         self.widget.pack_start(url_entry, False, False)
 
-        access = common.MODELACCESS[self.model]
-        for button, access_type in (
-                ('new', 'create'),
-                ('save', 'write'),
-                ):
-            self.buttons[button].props.sensitive = access[access_type]
+        self.set_buttons_sensitive()
 
         self.screen.signal_connect(self, 'record-message',
             self._record_message)
@@ -148,6 +148,7 @@ class Form(SignalEvent, TabContent):
         self.screen.signal_connect(self, 'record-saved', self._record_saved)
         self.screen.signal_connect(self, 'attachment-count',
                 self._attachment_count)
+        self.screen.signal_connect(self, 'unread-note', self._unread_note)
 
         if res_id not in (None, False):
             if isinstance(res_id, (int, long)):
@@ -216,6 +217,35 @@ class Form(SignalEvent, TabContent):
         self.buttons['attach'].props.sensitive = bool(
             record.id >= 0 if record else False)
 
+    def sig_note(self, widget=None):
+        record = self.screen.current_record
+        if not record or record.id < 0:
+            return
+        Note(record,
+            lambda: self.update_unread_note(reload=True))
+
+    def update_unread_note(self, reload=False):
+        record = self.screen.current_record
+        if record:
+            unread = record.get_unread_note(reload=reload)
+        else:
+            unread = 0
+        self._unread_note(None, unread)
+
+    def _unread_note(self, widget, signal_data):
+        label = _('Note(%d)') % signal_data
+        self.buttons['note'].set_label(label)
+        if signal_data:
+            self.buttons['note'].set_stock_id('tryton-note-hi')
+        else:
+            self.buttons['note'].set_stock_id('tryton-note')
+        record = self.screen.current_record
+        if not record or record.id < 0:
+            sensitive = False
+        else:
+            sensitive = True
+        self.buttons['note'].props.sensitive = sensitive
+
     def sig_switch(self, widget=None):
         if not self.modified_save():
             return
@@ -297,8 +327,17 @@ class Form(SignalEvent, TabContent):
             self.title.set_label('%s @ %s' % (self.name, revision))
         else:
             self.title.set_label(self.name)
-        for button in ('new', 'save'):
-            self.buttons[button].props.sensitive = not revision
+        self.set_buttons_sensitive(revision)
+
+    def set_buttons_sensitive(self, revision=None):
+        if not revision:
+            access = common.MODELACCESS[self.model]
+            self.buttons['new'].props.sensitive = access['create']
+            self.buttons['save'].props.sensitive = (
+                access['create'] or access['write'])
+        else:
+            for button in ['new', 'save']:
+                self.buttons[button].props.sensitive = False
 
     def sig_remove(self, widget=None):
         if not common.MODELACCESS[self.model]['delete']:
@@ -346,7 +385,8 @@ class Form(SignalEvent, TabContent):
         if widget:
             # Called from button so we must save the tree state
             self.screen.save_tree_state()
-        if not common.MODELACCESS[self.model]['write']:
+        if not (common.MODELACCESS[self.model]['write']
+                or common.MODELACCESS[self.model]['create']):
             return
         if self.screen.save_current():
             self.message_info(_('Record saved.'), gtk.MESSAGE_INFO)
@@ -473,7 +513,7 @@ class Form(SignalEvent, TabContent):
         if self.screen.modified():
             value = sur_3b(
                 _('This record has been modified\n'
-                    'do you want to save it ?'))
+                    'do you want to save it?'))
             if value == 'ok':
                 return self.sig_save(None)
             if value == 'ko':
